==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/VradiUser.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface VradiUser extends BusinessEntity, WikittyUser {     String EXT_VRADIUSER = "VradiUser";
     String FIELD_VRADIUSER_EMAIL = "email";
     String FQ_FIELD_VRADIUSER_EMAIL = EXT_VRADIUSER + ".email";
    /**
     * getEmail :
     * @return String 
     */

     String getEmail();

    /**
     * setEmail :
     * @param email 
     */

     void setEmail(String email);

    /**
     * getLogin :
     * @return String 
     */

     String getLogin();

    /**
     * setLogin :
     * @param login 
     */

     void setLogin(String login);

    /**
     * getPassword :
     * @return String 
     */

     String getPassword();

    /**
     * setPassword :
     * @param password 
     */

     void setPassword(String password);


} //VradiUser

==> vradi-entities-0.3-sources.jar: com/jurismarches/vradi/entities/VradiUser.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface VradiUser extends BusinessEntity, WikittyUser {     String EXT_VRADIUSER = "VradiUser";
     String FIELD_VRADIUSER_EMAIL = "email";
     String FQ_FIELD_VRADIUSER_EMAIL = EXT_VRADIUSER + ".email";
    /**
     * getEmail :
     * @return String 
     */

     String getEmail();

    /**
     * setEmail :
     * @param email 
     */

     void setEmail(String email);

    /**
     * getLogin :
     * @return String 
     */

     String getLogin();

    /**
     * setLogin :
     * @param login 
     */

     void setLogin(String login);

    /**
     * getPassword :
     * @return String 
     */

     String getPassword();

    /**
     * setPassword :
     * @param password 
     */

     void setPassword(String password);


} //VradiUser
